@@ -6,7 +6,7 @@ use Kavorka -all;
 use utf8;
 
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 # V[m] | CH | {CH}C[v][m] | D | F | Hpv | W | Sid | N | Other | NT
 
@@ -91,7 +91,7 @@ my $parser = qr {
     <nocontext:>
     <String>
     <objrule:  TE::String>        <[Tgc]>+
-    <objrule:  TE::Tgc>           <S> | <Vm> | <CH> | <CHCvm> | <D> | <F> | <W> | <Sid> | <N> | <Other> | <NT>
+    <objrule:  TE::Tgc>           <ws: (\s++)*> <S> | <Vm> | <CH> | <CHCvm> | <D> | <F> | <W> | <Sid> | <N> | <Other> | <NT>
     <objrule:  TE::Vm>            <V><m_>
     <objrule:  TE::CHCvm>         <CH__><C><v_><m_>
     <objtoken: TE::CH>            ([క-హౘ-ౚ])(్\b)
